#########################
Search and the django CMS
#########################

For powerful full-text search within the django CMS, we suggest using
`Haystack`_ together with `django-cms-search`_.

.. _Haystack: http://haystacksearch.org/
.. _django-cms-search: https://github.com/piquadrat/django-cms-search
